/**
 * @author James Tomkinson
 * @copyright StreamBase Systems, Inc. 2012
 */
package com.streambase.services.adapters.webservice;


import java.util.ArrayList;

import org.slf4j.Logger;
import com.streambase.services.webservicesclients.JerseyClient1;

import com.streambase.sb.*;
import com.streambase.sb.Schema.Field;
import com.streambase.sb.operator.*;

/**
 * Generated by JDT StreamBase Client Templates (Version: 7.1.8.1202221217).
 *
 */
public class GetStringWebServiceAdapter extends Operator implements
		Parameterizable {

	public static final long serialVersionUID = 1330467211649L;
	private Logger logger;
	// Properties
	private String URL;
	private String displayName = "Get String Web Service";
	// Local variables
	private int inputPorts = 1;
	private int outputPorts = 1;
	private int nextOutputPort = 0;
	private Schema outputSchema; // caches the Schemas given during typecheck for use at processTuple
	private Schema inputSchema; // caches the Schemas given during typecheck for use at processTuple
    private static final String BASE_URI = "http://localhost:8080/SetAndGetExample/resources";
	private JerseyClient1 client;

	/**
	 * The constructor is called when the Operator instance is created
	 */
	public GetStringWebServiceAdapter() {
		super();
		logger = getLogger();
		setPortHints(1, 1);
		setDisplayName(displayName);
		setShortDisplayName(this.getClass().getSimpleName());
		setURL( BASE_URI );

	}

	/**
	 * The typecheck method is called after the Operator instance is connected in the StreamBase
	 * application, allowing the Operator to validate its properties. 
	 */
	public void typecheck() throws TypecheckException {
		// typecheck: require a specific number of input ports
		requireInputPortCount(inputPorts);

		// note that we will not check the input schema, as this will only trigger the service (allow no field input stream)
		requireInputPortCount(1);
		
		ArrayList<Field> outFields = new ArrayList();
		outFields.add(new Field("message", CompleteDataType.forString()));
		outputSchema = new Schema( null, outFields );
		setOutputSchema(0, outputSchema);
	}

	/**
	 * This method will be called by the StreamBase server for each Tuple given
	 * to the Operator to process. This is the only time an operator should 
	 * enqueue output Tuples.
	 */
	public void processTuple(int inputPort, Tuple tuple)
			throws StreamBaseException {
		if (logger.isInfoEnabled()) {
			logger.info("operator processing a tuple at input port" + inputPort);
		}
		// TODO only the first input port is processed; see the template code for typecheck()
		if (inputPort > 0) {
			logger.info("operator skipping tuple at input port" + inputPort);
			return;
		}

		// create a new output tuple from the Schema at the port we are about to send to
		Tuple out = getOutputSchema(nextOutputPort).createTuple();

		out.setString(0, client.getString());
		sendOutput(0, out);
	}

	/**
	 * If typecheck succeeds, the init method is called before the StreamBase application
	 * is started. 
	 */
	public void init() throws StreamBaseException {
		client = new JerseyClient1( BASE_URI );
		super.init();
	}

	/**
	 *  The shutdown method is called when the StreamBase server is in the process of shutting down.
	 */
	public void shutdown() {

	}

	/***************************************************************************************
	 * The getter and setter methods provided by the Parameterizable object.               *
	 * StreamBase Studio uses them to determine the name and type of each property         *
	 * and obviously, to set and get the property values.                                  *
	 ***************************************************************************************/

	public void setURL(String URL) {
		this.URL = URL;
	}

	public String getURL() {
		return this.URL;
	}

	/** For detailed information about shouldEnable methods, see interface Parameterizable java doc 
	 *  @see Parameterizable 
	 */

	public boolean shouldEnableURL() {
		// TODO implement custom enablement logic here 
		return true;
	}

}
