/**
 * @author James Tomkinson
 * @copyright StreamBase Systems, Inc. 2012
 */

package com.streambase.services.adapters.webservice;


import org.slf4j.Logger;
import com.streambase.services.webservicesclients.JerseyClient1;
import com.streambase.sb.*;
import com.streambase.sb.adapter.*;
import com.streambase.sb.operator.*;
import com.sun.org.apache.xalan.internal.xsltc.compiler.util.TypeCheckError;

/**
 * Generated by JDT StreamBase Client Templates (Version: 7.1.8.1202221217).

 */
public class SetStringRESTwebService extends OutputAdapter implements
		Parameterizable {

	public static final long serialVersionUID = 1330465824889L;
	private Logger logger;
	// Properties
	private String URL;
	private String displayName = "Set String Output Adapter";
    private static final String BASE_URI = "http://localhost:8080/SetAndGetExample/resources";
	private Schema inputSchema; // caches the Schemas given during typecheck for use at processTuple
	private JerseyClient1 client;

	/**
	 * The constructor is called when the Adapter instance is created, but before the Adapter 
	 * is connected to the StreamBase application. We recommended that you set the initial input 
	 * port and output port count in the constructor by calling setPortHints(inPortCount, outPortCount). 
	 * The default is no input ports or output ports. The constructor may also set default values for 
	 * adapter parameters. These values will be displayed in StreamBase Studio when a new adapter is 
	 * dragged to the canvas, and serve as the default values for omitted optional parameters.
	 */
	public SetStringRESTwebService() {
		super();
		logger = getLogger();
		setPortHints(1, 0);
		setDisplayName(displayName);
		setShortDisplayName(this.getClass().getSimpleName());
		setURL( BASE_URI );
	}

	/**
	 * Typecheck this adapter.  
	 */
	public void typecheck() throws TypecheckException {
		requireInputPortCount(1);
		inputSchema = getInputSchema(0);
		Schema.Field [] fields =  inputSchema.getFields();
		if( ! fields[0].getCompleteDataType().equals(CompleteDataType.forString())) {
			throw new TypecheckException("first input field must be of type string");
		}
	}

	@Override
	public void init() throws StreamBaseException {
		client = new JerseyClient1( BASE_URI );
		super.init();
	}

	/**
	 * This method will be called by the StreamBase server for each
	 * Tuple given to the adapter to process.  
	 * 
	 * @param inputPort the input port that the tuple is from (ports are zero based)
	 * @param tuple the tuple from the given input port
	 * @throws StreamBaseException Terminates the application. 
	 */
	public void processTuple(int inputPort, Tuple tuple)
			throws StreamBaseException {
		if (logger.isInfoEnabled())
			logger.info("processing a tuple at input port " + inputPort);
		String val = "";
		if( ! tuple.isNull(0)) {
			val = tuple.getString(0);
		}
		client.setString(val);
	}

	/***************************************************************************************
	 * The getter and setter methods provided by the Parameterizable object.               *
	 * StreamBase Studio uses them to determine the name and type of each property         *
	 * and obviously, to set and get the property values.                                  *
	 ***************************************************************************************/

	public void setURL(String URL) {
		this.URL = URL;
	}

	public String getURL() {
		return this.URL;
	}

	/** For detailed information about shouldEnable methods, see interface Parameterizable java doc 
	 *  @see Parameterizable 
	 */

	public boolean shouldEnableURL() {
		// TODO implement custom enablement logic here 
		return true;
	}

}
